@@ -1,12 +1,12 @@
 import logging
 import os
+import re
 import sys
 
 from cliff.app import App
 from cliff.commandmanager import CommandManager
 
 from enough.version import __version__
-from enough.common.dotenough import DotEnough
 
 os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'enough.settings')
 
@@ -42,9 +42,30 @@ class EnoughApp(App):
         parser.add_argument('--domain', default='enough.community', help='Enough domain name')
         return parser
 
+    @staticmethod
+    def remap(argv):
+        home = os.path.expanduser('~/.enough')
+
+        def remap(s):
+            s = re.sub(r'^/\S+/.enough', home, s)
+            s = re.sub(r'=/\S+/.enough', f'={home}', s)
+            return s
+        return [remap(a) for a in argv]
+
+    @staticmethod
+    def preserve_ownership():
+        uid = os.geteuid()
+        home = os.path.expanduser('~/.enough')
+        if not uid == 0 or not os.path.exists(home):
+            return False
+        home_uid = os.stat(home).st_uid
+        if uid != home_uid:
+            os.system(f'chown -R {home_uid} {home}')
+        return True
+
     def run(self, argv):
-        r = super().run(DotEnough.remap(argv))
-        DotEnough.preserve_ownership()
+        r = super().run(self.remap(argv))
+        self.preserve_ownership()
         return r
 
 
