@@ -7,98 +7,107 @@ import sh
 import tempfile
 import textwrap
 
-from enough import settings
-
 log = logging.getLogger(__name__)
 
 
-def parse_output(output):
-    json_result = re.sub(r'.*?=> ', '', output)
-    return json.loads(json_result)
-
-
-def bake_ansible_playbook():
-    args = ['-i', 'inventory', '-i', 'development-inventory']
-    if settings.CONFIG_DIR != '.':
-        args.extend(['-i', f'{settings.CONFIG_DIR}/inventory'])
-        args.extend(['-i', f'{settings.CONFIG_DIR}/development-inventory'])
-    return sh.ansible_playbook.bake(
-        *args,
-        _tee=True,
-        _out=lambda x: log.info(x.strip()),
-        _err=lambda x: log.info(x.strip()),
-        _truncate_exc=False,
-        _cwd=settings.SHARE_DIR,
-        _env={'ANSIBLE_NOCOLOR': 'true'},
-    )
-
-
-def ansible_inventory():
-    args = ['--list', '-i', 'inventory', '-i', 'development-inventory']
-    if settings.CONFIG_DIR != '.':
-        args.extend(['-i', f'{settings.CONFIG_DIR}/inventory'])
-        args.extend(['-i', f'{settings.CONFIG_DIR}/development-inventory'])
-    i = sh.ansible_inventory(
-        *args,
-        _cwd=settings.SHARE_DIR,
-    )
-    return json.loads(i.stdout.decode('utf-8'))
-
-
-def _flat_inventory(i, content):
-    hosts = content.get('hosts', [])
-    for child in content.get('children', []):
-        hosts.extend(_flat_inventory(i, i[child]))
-    return hosts
-
-
-def get_groups():
-    i = ansible_inventory()
-    del i['_meta']
-    groups = {}
-    for name, content in i.items():
-        groups[name] = _flat_inventory(i, content)
-    return groups
-
-
-def get_variable(role, variable, host):
-    with tempfile.NamedTemporaryFile() as f:
-        # the sourrounding "> <" are to prevent conversion to int, list or whatever
-        playbook = textwrap.dedent("""
-        ---
-        - hosts: all
-          gather_facts: false
-
-          roles:
-            - role: "{{ rolevar }}"
-
-          tasks:
-            - name: print variable
-              debug:
-                msg: ">{{ variable }}<"
-        """)
-        f.write(bytearray(playbook, 'utf-8'))
-        f.flush()
-        print(playbook)
-        r = bake_ansible_playbook()(
-            '-e', f'rolevar={role}',
-            '-e', 'variable={{ ' + variable + ' }}',
-            '--limit', host,
-            '--start-at-task=print variable',
-            f.name)
-        m = re.search(r'"msg": ">(.*)<"$', r.stdout.decode('utf-8'), re.MULTILINE)
-        return m.group(1)
-
-
-class Playbook(object):
-
-    class NoPasswordException(Exception):
-        pass
+class Ansible(object):
 
     def __init__(self, config_dir, share_dir):
         self.config_dir = config_dir
         self.share_dir = share_dir
 
+    def bake_ansible_playbook(self):
+        args = [
+            '-i', 'inventory',
+            '-i', 'development-inventory',
+            '--extra-vars', f'enough_domain_config_directory={self.config_dir}',
+        ]
+        if self.config_dir != '.':
+            args.extend(['-i', f'{self.config_dir}/inventory'])
+            args.extend(['-i', f'{self.config_dir}/development-inventory'])
+        return sh.ansible_playbook.bake(
+            *args,
+            _tee=True,
+            _out=lambda x: log.info(x.strip()),
+            _err=lambda x: log.info(x.strip()),
+            _truncate_exc=False,
+            _cwd=self.share_dir,
+            _env={'ANSIBLE_NOCOLOR': 'true'},
+        )
+
+    def vault_password_option(self):
+        password_file = f'{self.config_dir}.pass'
+        if os.path.exists(password_file):
+            return f'--vault-password-file={password_file}'
+        else:
+            log.info(f'no decryption because {password_file} does not exist')
+            return None
+
+    def ansible_inventory(self):
+        args = [
+            '--list',
+            '-i', 'inventory',
+            '-i', 'development-inventory',
+        ]
+        if self.config_dir != '.':
+            args.extend(['-i', f'{self.config_dir}/inventory'])
+            args.extend(['-i', f'{self.config_dir}/development-inventory'])
+        if self.vault_password_option():
+            args.append(self.vault_password_option())
+        i = sh.ansible_inventory(
+            *args,
+            _cwd=self.share_dir,
+        )
+        return json.loads(i.stdout.decode('utf-8'))
+
+    def _flat_inventory(self, i, content):
+        hosts = content.get('hosts', [])
+        for child in content.get('children', []):
+            hosts.extend(self._flat_inventory(i, i[child]))
+        return hosts
+
+    def get_groups(self):
+        i = self.ansible_inventory()
+        del i['_meta']
+        groups = {}
+        for name, content in i.items():
+            groups[name] = self._flat_inventory(i, content)
+        return groups
+
+    def get_variable(self, role, variable, host):
+        with tempfile.NamedTemporaryFile() as f:
+            # the sourrounding "> <" are to prevent conversion to int, list or whatever
+            playbook = textwrap.dedent("""
+            ---
+            - hosts: all
+              gather_facts: false
+
+              roles:
+                - role: "{{ rolevar }}"
+
+              tasks:
+                - name: print variable
+                  debug:
+                    msg: ">{{ variable }}<"
+            """)
+            f.write(bytearray(playbook, 'utf-8'))
+            f.flush()
+            print(playbook)
+            r = self.bake_ansible_playbook()(
+                '-e', f'rolevar={role}',
+                '-e', 'variable={{ ' + variable + ' }}',
+                '--limit', host,
+                '--start-at-task=print variable',
+                f.name)
+            m = re.search(r'"msg": ">(.*)<"$', r.stdout.decode('utf-8'), re.MULTILINE)
+            return m.group(1)
+
+
+class Playbook(Ansible):
+
+    class NoPasswordException(Exception):
+        pass
+
     @staticmethod
     def is_encrypted(p):
         if not os.path.exists(p):
@@ -137,14 +146,6 @@ class Playbook(object):
             )
         return True
 
-    def vault_password_option(self):
-        password_file = f'{self.config_dir}.pass'
-        if os.path.exists(password_file):
-            return f'--vault-password-file={password_file}'
-        else:
-            log.info(f'no decryption because {password_file} does not exist')
-            return None
-
     @staticmethod
     def roles_path(d):
         r = glob.glob(f'{d}/molecule/*/roles')
@@ -153,6 +154,7 @@ class Playbook(object):
 
     def bake(self):
         args = [
+            '--extra-vars', f'enough_domain_config_directory={self.config_dir}',
             '-i', f'{self.share_dir}/inventory',
         ]
         if self.vault_password_option():
