@@ -98,8 +98,8 @@ class HostOpenStack(Host):
             s.delete()
 
 
-def host_factory(**kwargs):
+def host_factory(config_dir=settings.CONFIG_DIR, share_dir=settings.SHARE_DIR, **kwargs):
     if kwargs['driver'] == 'openstack':
-        return HostOpenStack(settings.CONFIG_DIR, settings.SHARE_DIR, **kwargs)
+        return HostOpenStack(config_dir, share_dir, **kwargs)
     else:
-        return HostDocker(settings.CONFIG_DIR, settings.SHARE_DIR, **kwargs)
+        return HostDocker(config_dir, share_dir, **kwargs)
