@@ -1,5 +1,5 @@
-from abc import ABC, abstractmethod
 import logging
+import os
 import re
 import requests
 
@@ -11,25 +11,34 @@ from enough.common import ansible_utils
 log = logging.getLogger(__name__)
 
 
-class Service(ABC):
+class Service(object):
 
     def __init__(self, config_dir, share_dir):
         self.config_dir = config_dir
         self.share_dir = share_dir
         suffix = '-service-hosts'
-        groups = ansible_utils.get_groups()
+        groups = ansible_utils.Ansible(config_dir, share_dir).get_groups()
         self.service2hosts = {
             name.replace(suffix, ''): hosts for name, hosts in groups.items()
             if name.endswith(suffix)
         }
 
-    @abstractmethod
-    def create_or_update(self):
-        pass
+    def service_from_host(self, host):
+        found = None
+        hosts_count = 0
+        for service, hosts in self.service2hosts.items():
+            if host in hosts:
+                if hosts_count > 0 and len(hosts) > hosts_count:
+                    continue
+                found = service
+                hosts_count = len(hosts)
+        return found
 
 
 class ServiceDocker(Service):
-    pass
+
+    def create_or_update(self):
+        pass
 
 
 class ServiceOpenStack(Service):
@@ -72,21 +81,25 @@ class ServiceOpenStack(Service):
         return True
 
     def create_or_update(self):
-        self.maybe_delegate_dns()
         hosts = self.service2hosts[self.args['name']]
         h = openstack.Heat(self.config_dir, self.dotenough.clouds_file)
         h.create_missings(hosts, self.dotenough.public_key())
+        self.maybe_delegate_dns()
         playbook = ansible_utils.Playbook(self.config_dir, self.share_dir)
+        if os.path.isabs(self.args["playbook"]):
+            playbook_file = self.args["playbook"]
+        else:
+            playbook_file = f'{self.config_dir}/{self.args["playbook"]}'
         playbook.run([
             f'--private-key={self.dotenough.private_key()}',
             '--limit', ','.join(hosts + ['localhost']),
-            f'{self.share_dir}/{self.args["playbook"]}',
+            playbook_file,
         ])
         return {'fqdn': f'{self.args["name"]}.{self.args["domain"]}'}
 
 
-def service_factory(**kwargs):
+def service_factory(config_dir=settings.CONFIG_DIR, share_dir=settings.SHARE_DIR, **kwargs):
     if kwargs['driver'] == 'openstack':
-        return ServiceOpenStack(settings.CONFIG_DIR, settings.SHARE_DIR, **kwargs)
+        return ServiceOpenStack(config_dir, share_dir, **kwargs)
     else:
-        return ServiceDocker(settings.CONFIG_DIR, settings.SHARE_DIR, **kwargs)
+        return ServiceDocker(config_dir, share_dir, **kwargs)
