@@ -4,10 +4,9 @@ testinfra_hosts = ['cloud-host']
 def test_nextcloud(host):
     cmd = host.run("""
     set -xe
-    d=/dev/sdb
-    test -e /dev/sdb || d=/dev/vda
-    mount | grep $d | grep /var/lib/docker
-    curl --silent https://cloud.$(hostname -d)/login | grep --quiet 'Forgot pass'
+    mount | grep /dev/mapper/spare
+    curl --silent https://cloud.$(hostname -d)/login | \
+         grep --quiet 'This application requires JavaScript'
     """)
     print(cmd.stdout)
     print(cmd.stderr)
@@ -18,7 +17,8 @@ def test_nextcloud_via_tor(host):
     cmd = host.run("""
     set -xe
     hostname=$(sudo cat /var/lib/tor/services/cloud/hostname)
-    torsocks curl --silent http://$hostname/login | grep --quiet 'Forgot pass'
+    torsocks curl --silent http://$hostname/login | \
+             grep --quiet 'This application requires JavaScript'
     """)
     print(cmd.stdout)
     print(cmd.stderr)
