@@ -6,10 +6,14 @@ def test_infrastructure2_encrypted_volume(host):
     set -xe
     test -e /dev/mapper/spare
     grep -q /opt /etc/fstab
+    test -e /opt/docker/image
+    test -e /opt/snap/hello-world
+    grep -q snap /etc/fstab
     """)
     print(cmd.stdout)
     print(cmd.stderr)
     assert 0 == cmd.rc
 
     # set by infrastructure/test-encrypted-volume.yml
-    host.file("/etc/cryptsetup/keyfile").content == "PASSWORD"
+    with host.sudo():
+        host.file("/etc/cryptsetup/keyfile").content == "PASSWORD"
