@@ -5,7 +5,9 @@ def test_encrypted_volume(host):
     cmd = host.run("""
     set -xe
     test -e /dev/mapper/spare
-    grep -q /opt /etc/fstab
+    grep -q /srv /etc/fstab
+    test ! -e /srv/docker
+    test ! -e /srv/snap
     """)
     print(cmd.stdout)
     print(cmd.stderr)
