@@ -1,4 +1,3 @@
-import json
 import pytest
 import shutil
 import yaml
@@ -7,16 +6,11 @@ from enough import settings
 from enough.common import ansible_utils
 
 
-def test_parse_output():
-    data = {"changed": False}
-    output = '51.68.81.22 | SUCCESS => ' + json.dumps(data)
-    assert ansible_utils.parse_output(output) == data
-
-
 def test_get_variable():
     defaults = yaml.load(open('molecule/api/roles/api/defaults/main.yml'))
     variable = 'api_admin_password'
-    value = ansible_utils.get_variable('api', variable, 'api-host')
+    ansible = ansible_utils.Ansible(settings.CONFIG_DIR, settings.SHARE_DIR)
+    value = ansible.get_variable('api', variable, 'api-host')
     assert defaults[variable] == value
 
 
@@ -84,12 +78,12 @@ def test_playbook_run_no_args(mocker):
 
 
 def test_ansible_inventory():
-    i = ansible_utils.ansible_inventory()
+    i = ansible_utils.Ansible(settings.CONFIG_DIR, settings.SHARE_DIR).ansible_inventory()
     assert '_meta' in i
 
 
 def test_get_groups():
-    i = ansible_utils.get_groups()
+    i = ansible_utils.Ansible(settings.CONFIG_DIR, settings.SHARE_DIR).get_groups()
     assert 'all-hosts' in i
 
 
@@ -117,7 +111,8 @@ def test_flat_inventory():
             'hosts': ['host70', 'host71'],
         }
     }
+    ansible = ansible_utils.Ansible(settings.CONFIG_DIR, settings.SHARE_DIR)
     expected = ['host10', 'host11', 'host20', 'host30', 'host31', 'host50', 'host51']
-    assert sorted(ansible_utils._flat_inventory(inventory, inventory['group1'])) == expected
+    assert sorted(ansible._flat_inventory(inventory, inventory['group1'])) == expected
     expected = ['host70', 'host71']
-    assert sorted(ansible_utils._flat_inventory(inventory, inventory['group7'])) == expected
+    assert sorted(ansible._flat_inventory(inventory, inventory['group7'])) == expected
