@@ -28,3 +28,10 @@ def test_openstack_create_or_update(tmpdir, openstack_name, requests_mock):
     # the second time around the hosts.yml are reused
     r = s.create_or_update()
     assert r['fqdn'] == f'essential.{domain}'
+
+
+def test_service_from_host(tmpdir):
+    s = service.Service(settings.CONFIG_DIR, settings.SHARE_DIR)
+    assert s.service_from_host('bind-host') == 'essential'
+    assert s.service_from_host('cloud-host') == 'cloud'
+    assert s.service_from_host('unknown-host') is None
